@@ -3,7 +3,13 @@ import os
 import tempfile
 import unittest
 
-from flask import Flask, make_response, render_template, request
+from flask import (
+    Flask,
+    make_response,
+    render_template,
+    request,
+    stream_with_context,
+)
 from flask_caching import Cache
 
 from flask_compress import Compress, DictCache
@@ -63,6 +69,12 @@ class DefaultsTest(unittest.TestCase):
             self.app.config["COMPRESS_ALGORITHM"], ["zstd", "br", "gzip", "deflate"]
         )
 
+    def test_algorithm_streaming(self):
+        """Tests COMPRESS_ALGORITHM_STREAMING default value is correctly set."""
+        self.assertEqual(
+            self.app.config["COMPRESS_ALGORITHM_STREAMING"], ["zstd", "br", "deflate"]
+        )
+
     def test_default_deflate_settings(self):
         """Tests COMPRESS_DELATE_LEVEL default value is correctly set."""
         self.assertEqual(self.app.config["COMPRESS_DEFLATE_LEVEL"], -1)
@@ -96,6 +108,13 @@ class DefaultsTest(unittest.TestCase):
         is correctly set."""
         self.assertEqual(self.app.config["COMPRESS_EVALUATE_CONDITIONAL_REQUEST"], True)
 
+    def test_streaming_endpoint_conditional(self):
+        """Tests COMPRESS_STREAMING_ENDPOINT_CONDITIONAL default value
+        is correctly set."""
+        self.assertEqual(
+            self.app.config["COMPRESS_STREAMING_ENDPOINT_CONDITIONAL"], ["static"]
+        )
+
 
 class InitTests(unittest.TestCase):
     def setUp(self):
@@ -116,7 +135,6 @@ class UrlTests(unittest.TestCase):
         self.app.testing = True
 
         small_path = os.path.join(os.getcwd(), "tests", "templates", "small.html")
-
         large_path = os.path.join(os.getcwd(), "tests", "templates", "large.html")
 
         self.small_size = os.path.getsize(small_path) - 1
@@ -443,7 +461,6 @@ class StreamTests(unittest.TestCase):
     def setUp(self):
         self.app = Flask(__name__)
         self.app.testing = True
-        self.app.config["COMPRESS_STREAMS"] = False
 
         self.file_path = os.path.join(os.getcwd(), "tests", "templates", "large.html")
         self.file_size = os.path.getsize(self.file_path)
@@ -457,8 +474,9 @@ class StreamTests(unittest.TestCase):
             return self.app.response_class(_stream(), mimetype="text/html")
 
     def test_no_compression_stream(self):
-        """Tests compression is skipped when response is streamed"""
+        """Tests compression is skipped when COMPRESS_STREAMS is False"""
         Compress(self.app)
+        self.app.config["COMPRESS_STREAMS"] = False
         client = self.app.test_client()
         for algorithm in ("gzip", "deflate", "br", "zstd", ""):
             headers = [("Accept-Encoding", algorithm)]
@@ -467,17 +485,65 @@ class StreamTests(unittest.TestCase):
             self.assertEqual(response.is_streamed, True)
             self.assertEqual(self.file_size, len(response.data))
 
-    def test_disabled_stream(self):
-        """Test that stream compression can be disabled."""
+    def test_compression_stream(self):
         Compress(self.app)
-        self.app.config["COMPRESS_STREAMS"] = True
         client = self.app.test_client()
-        for algorithm in ("gzip", "deflate", "br", "zstd"):
+        for algorithm in ("deflate", "br", "zstd"):
             headers = [("Accept-Encoding", algorithm)]
             response = client.get("/stream/large", headers=headers)
             self.assertIn("Content-Encoding", response.headers)
+            self.assertEqual(response.status_code, 200)
+            self.assertEqual(response.is_streamed, True)
             self.assertGreater(self.file_size, len(response.data))
 
+        # gzip is not supported for streamed responses
+        headers = [("Accept-Encoding", "gzip")]
+        response = client.get("/stream/large", headers=headers)
+        self.assertNotIn("Content-Encoding", response.headers)
+        self.assertEqual(response.status_code, 200)
+        self.assertEqual(response.is_streamed, True)
+        self.assertEqual(self.file_size, len(response.data))
+
+
+class StreamTestsWithETags(unittest.TestCase):
+    def setUp(self):
+        self.app = Flask(__name__)
+        self.app.testing = True
+
+        self.file_path = os.path.join(os.getcwd(), "tests", "templates", "large.html")
+        self.file_size = os.path.getsize(self.file_path)
+
+        Compress(self.app)
+
+        @self.app.route("/stream/large")
+        def stream():
+            def _stream():
+                with open(self.file_path) as f:
+                    yield from f.readlines()
+
+            rv = make_response(stream_with_context(_stream()))
+            rv.mimetype = "text/html"
+            rv.set_etag("stream-etag", weak=False)
+            return rv
+
+    def test_conditionals_are_skipped_on_streaming(self):
+        client = self.app.test_client()
+        r1 = client.get("/stream/large", headers=[("Accept-Encoding", "br")])
+        tag, is_weak = r1.get_etag()
+        self.assertEqual(r1.status_code, 200)
+        self.assertEqual(r1.is_streamed, True)
+        self.assertEqual(tag, "stream-etag:br")
+        self.assertFalse(is_weak)
+        r1.close()
+
+        r2 = client.get(
+            "/stream/large",
+            headers=[("Accept-Encoding", "br"), ("If-None-Match", r1.headers["ETag"])],
+        )
+        self.assertEqual(r2.status_code, 200)  # Should be 200, not 304
+        self.assertEqual(r2.is_streamed, True)
+        r2.close()
+
 
 class CachingCompressionTests(unittest.TestCase):
     def setUp(self):
